@@ -157,7 +157,7 @@ void send_warning_orphan_msg(unsigned long inst_id, int32_t warn_id);
 void send_cmd_orphan_msg(unsigned long inst_id, int32_t cmd_id);
 
 void send_dec_inputbuf_orphan_msg(v4l2_daemon_inst *h, vsi_v4l2_msg *v4l2_msg,
-                                  int32_t inbuf_idx);
+                                  int32_t inbuf_idx, uint32_t flag);
 
 void send_dec_outputbuf_orphan_msg(v4l2_daemon_inst *h, vsi_v4l2_msg *v4l2_msg,
                                    int32_t outbuf_idx, int32_t out_buff_size,
