@@ -570,11 +570,9 @@ v4l2_inst_dec_event hevc_dec_decode(v4l2_dec_inst *h, vsi_v4l2_msg *v4l2_msg) {
 
       case DEC_PIC_DECODED:
         h->dec_pic_id++;
-#ifdef NXP_TIMESTAMP_MANAGER
         re_dec_event = DEC_PIC_DECODED_EVENT;
         goto update_input;
-#endif
-        break;
+        //break;
 
       case DEC_PENDING_FLUSH:
 
@@ -600,10 +598,8 @@ v4l2_inst_dec_event hevc_dec_decode(v4l2_dec_inst *h, vsi_v4l2_msg *v4l2_msg) {
         break;
 
       case DEC_PIC_CONSUMED:
-#ifdef NXP_TIMESTAMP_MANAGER
-        re_dec_event = DEC_DECODING_FAILED_EVENT;
+        re_dec_event = DEC_DECODING_ERROR_EVENT;
         goto update_input;
-#endif
 
       case DEC_STRM_PROCESSED:
       case DEC_NONREF_PIC_SKIPPED:
@@ -615,7 +611,9 @@ v4l2_inst_dec_event hevc_dec_decode(v4l2_dec_inst *h, vsi_v4l2_msg *v4l2_msg) {
          * corrupting next picture
          * pic_rdy = 0; */
         if (dec_output.data_left == dec_input.data_len) {
+          re_dec_event = DEC_DECODING_ERROR_EVENT;
           in_mem->logical_size = 0;
+          h->consumed_len += dec_input.data_len;
           goto end;
         }
         break;
