@@ -362,25 +362,21 @@ v4l2_inst_dec_event mpeg2_dec_decode(v4l2_dec_inst* h, vsi_v4l2_msg* v4l2_msg) {
           goto end;
         }
         h->dec_pic_id++;
-#ifdef NXP_TIMESTAMP_MANAGER
-        h->consumed_len += dec_input.data_len - dec_output.data_left;
         re_dec_event = DEC_PIC_DECODED_EVENT;
         goto update_input;
-#endif
-        break;
+        //break;
       case MPEG2DEC_PIC_CONSUMED:
-#ifdef NXP_TIMESTAMP_MANAGER
-        h->consumed_len += dec_input.data_len - dec_output.data_left;
-        re_dec_event = DEC_DECODING_FAILED_EVENT;
+        re_dec_event = DEC_DECODING_ERROR_EVENT;
         goto update_input;
-#endif
-        break;
+        //break;
       case MPEG2DEC_NONREF_PIC_SKIPPED:
       case MPEG2DEC_STRM_PROCESSED:
         break;
       case MPEG2DEC_BUF_EMPTY:
         if (dec_output.data_left == dec_input.data_len) {
+          re_dec_event = DEC_DECODING_ERROR_EVENT;
           in_mem->logical_size = 0;
+          h->consumed_len += dec_input.data_len;
           goto end;
         }
         break;
@@ -396,7 +392,6 @@ v4l2_inst_dec_event mpeg2_dec_decode(v4l2_dec_inst* h, vsi_v4l2_msg* v4l2_msg) {
 
         if (mpeg2_dec_check_res_change(h, &dec_info, &hbuf) != 0) {
           re_dec_event = DEC_SOURCE_CHANGE_EVENT;
-          h->consumed_len += dec_input.data_len - dec_output.data_left;
           goto update_input;
         }
 
@@ -468,6 +463,7 @@ error:
     goto end;
   }
 update_input:
+  h->consumed_len += dec_input.data_len - dec_output.data_left;
   mpeg2_update_input(in_mem, &dec_input, &dec_output);
 end:
   return re_dec_event;
