@@ -428,6 +428,7 @@ v4l2_inst_dec_event rv_dec_decode(v4l2_dec_inst *h, vsi_v4l2_msg *v4l2_msg) {
   if (h->decoder_inst == (void *)FAKE_DECODER_INST) {
     rv_priv->stream_mode = rv_get_stream_mode(&h->stream_in_mem);
     if (rv_priv->stream_mode == RV_MODE) {
+      h->consumed_len += h->stream_in_mem.logical_size;
       rv_dec_init_rv_mode(h);
       goto end;
     } else {
@@ -440,12 +441,15 @@ v4l2_inst_dec_event rv_dec_decode(v4l2_dec_inst *h, vsi_v4l2_msg *v4l2_msg) {
     if (rv_priv->total_slice_info_size == 0) {
       rv_priv->slice_info_num =
           rv_dec_parse_sliceinfo(in_mem, rv_priv->slice_info);
-      if (rv_priv->slice_info_num == 0) 
+      if (rv_priv->slice_info_num == 0) {
+        dec_input.data_len = in_mem->logical_size;
         goto update_input;
+      }
 
       rv_priv->total_slice_info_size = NEXT_MULTIPLE(
           16 + rv_priv->slice_info_num * 8 + 4, RV_SLICE_DATA_ALIGN);
       in_mem->logical_size -= rv_priv->total_slice_info_size;
+      h->consumed_len += rv_priv->total_slice_info_size;
 #if 0
             memmove((u8 *)in_mem->virtual_address, 
                     (u8 *)in_mem->virtual_address + rv_priv->total_slice_info_size,
@@ -501,20 +505,13 @@ v4l2_inst_dec_event rv_dec_decode(v4l2_dec_inst *h, vsi_v4l2_msg *v4l2_msg) {
           goto end;
         }
         h->dec_pic_id++;
-#ifdef NXP_TIMESTAMP_MANAGER
-        h->consumed_len += dec_input.data_len - dec_output.data_left;
         re_dec_event = DEC_PIC_DECODED_EVENT;
-        dec_input.data_len = dec_output.data_left;
-#endif
         goto update_input;
 
       case RVDEC_OK:
       case RVDEC_PIC_CONSUMED:
       case RVDEC_NONREF_PIC_SKIPPED:
-#ifdef NXP_TIMESTAMP_MANAGER
-        h->consumed_len += dec_input.data_len - dec_output.data_left;
-        re_dec_event = DEC_DECODING_FAILED_EVENT;
-#endif
+        re_dec_event = DEC_DECODING_ERROR_EVENT;
       goto update_input;
 
       case RVDEC_STRM_PROCESSED:
@@ -526,7 +523,9 @@ v4l2_inst_dec_event rv_dec_decode(v4l2_dec_inst *h, vsi_v4l2_msg *v4l2_msg) {
       case RVDEC_BUF_EMPTY:
       case RVDEC_STRM_ERROR:
         if (dec_output.data_left == dec_input.data_len) {
+          re_dec_event = DEC_DECODING_ERROR_EVENT;
           in_mem->logical_size = 0;
+          h->consumed_len += dec_input.data_len;
           goto end;
         }
         break;
@@ -593,6 +592,7 @@ v4l2_inst_dec_event rv_dec_decode(v4l2_dec_inst *h, vsi_v4l2_msg *v4l2_msg) {
   }
 
 update_input:
+  h->consumed_len += dec_input.data_len; //consume all data since logical_size will be cleared
   rv_priv->total_slice_info_size = 0;
   rv_update_input(in_mem, &dec_output);
 end:
