@@ -468,12 +468,10 @@ v4l2_inst_dec_event vp9_dec_decode(v4l2_dec_inst *h, vsi_v4l2_msg *v4l2_msg) {
         /* Picture is now ready */
         h->dec_pic_id++;
         sf_info->cur_frm_id++;
-#ifdef NXP_TIMESTAMP_MANAGER
         re_dec_event = DEC_PIC_DECODED_EVENT;
         goto update_input;
-#endif
-        dec_input.data_len = 0;
-        break;
+        //dec_input.data_len = 0;
+        //break;
 
       case DEC_PENDING_FLUSH:
         if (Vp9DecGetInfo(dec_inst, &dec_info) != DEC_OK) {
@@ -486,12 +484,10 @@ v4l2_inst_dec_event vp9_dec_decode(v4l2_dec_inst *h, vsi_v4l2_msg *v4l2_msg) {
 
       case DEC_PIC_CONSUMED:
         sf_info->cur_frm_id++;
-#ifdef NXP_TIMESTAMP_MANAGER
-        re_dec_event = DEC_DECODING_FAILED_EVENT;
+        re_dec_event = DEC_DECODING_ERROR_EVENT;
         goto update_input;
-#endif
-        dec_input.data_len = 0;
-        break;
+        //dec_input.data_len = 0;
+        //break;
 
       case DEC_WAITING_FOR_BUFFER:
         HANTRO_LOG(HANTRO_LEVEL_INFO, "Waiting for frame buffers\n");
