@@ -420,7 +420,7 @@ int32_t main(int32_t argc, char **argv) {
 
       /*  send command to worker. */
       if (cur_inst_p->flag & (1 << INST_FATAL_ERROR)) {
-        if (vsi_v4l2_cmd_p.msg.cmd_id == V4L2_DAEMON_VIDIOC_STREAMOFF
+        if (vsi_v4l2_cmd_p.msg.cmd_id == V4L2_DAEMON_VIDIOC_DESTROY_ENC
           || vsi_v4l2_cmd_p.msg.cmd_id == V4L2_DAEMON_VIDIOC_DESTROY_DEC
           || vsi_v4l2_cmd_p.msg.cmd_id == V4L2_DAEMON_VIDIOC_EXIT) {
           pthread_kill(cur_inst_p->tid, SIGKILL);
@@ -436,7 +436,7 @@ int32_t main(int32_t argc, char **argv) {
         send_cmd_to_worker(cur_inst_p, &vsi_v4l2_cmd_p.msg);
 
         /* if get STREAMOFF, wait worker's semphore, and destory inst.*/
-        if ((vsi_v4l2_cmd_p.msg.cmd_id == V4L2_DAEMON_VIDIOC_STREAMOFF)
+        if ((vsi_v4l2_cmd_p.msg.cmd_id == V4L2_DAEMON_VIDIOC_DESTROY_ENC)
             //                || (vsi_v4l2_cmd_p.msg.cmd_id ==
             //                V4L2_DAEMON_VIDIOC_STREAMOFF_CAPTURE)
             || (vsi_v4l2_cmd_p.msg.cmd_id == V4L2_DAEMON_VIDIOC_DESTROY_DEC) ||
